@@ -5,6 +5,7 @@ import shutil
 import socket
 import datetime
 import subprocess
+import numpy as np
 
 import ase.io
 import ase.build
@@ -13,7 +14,7 @@ from ase.calculators.calculator import (CalculationFailed, Calculator,
                                         CalculatorSetupError, Parameters,
                                         all_changes, register_calculator_class)
 
-__version__ = "0.2.4"
+__version__ = "0.2.5"
 __license__ = "MIT"
 __author__ = "Michael F. Herbst"
 __all__ = ["DFTK", "update", "build_sysimage", "remove_sysimage"]
@@ -93,7 +94,7 @@ def build_sysimage():
                                           "precompile.jl")
             julia("-e", f"""
                 using PackageCompiler;
-                create_sysimage([:DFTK, :JLD2, :JSON],
+                create_sysimage([:DFTK, :JLD2, :JSON3],
                 sysimage_path="sysimage.so",
                 precompile_execution_file="{precompilefile}")
             """, sysimage=False)
@@ -206,8 +207,12 @@ class DFTK(Calculator):
         with open(label + ".json", "r") as fp:
             saved_dict = json.load(fp)
         self.parameters = Parameters(saved_dict["parameters"])
-        self.results = saved_dict["results"]
         self.scfres = saved_dict.get("scfres", None)
+        self.results = saved_dict["results"]
+
+        # Some results need to be numpy arrays:
+        for key in ("forces", ):
+            self.results[key] = np.array(self.results[key])
 
         with io.StringIO(saved_dict["atoms"]) as fp:
             self.atoms = ase.io.read(fp, format="json")
